//Entity.h
#ifndef ENTITY_H
#define ENTITY_H

#include "main.h"
#include "SpriteBase.h"

class SpriteBase;


class Entity		//Entity represent all the "Entity's" in the game, the gloves and player
{
	public:

	//constructor initializes starting direction and mode
	Entity(int start_direction, int start_mode,int ID);

	~Entity(){}
	
	//screen positions
    void Set_xPos(int xPos);
    int Get_xPos();
	
	void Set_yPos(int yPos);
	int Get_yPos();
	
	//current direction the entity is moving
	void Set_Dir(int dir);
	int Get_Dir();

	//current mode/state of this entity, SETMODE CAN ONLY BE USED WITH PLAYER.
	void Set_Mode(int mode);
	int Get_Mode();

	//this is used with the enemies, state 1 is to the state to change to, time is how many frames, and state2 is the state to change back to
	void Set_State(int STATE1,int TIME,int STATE2);

    //this moves our entity's
	void Move_Up();
	void Move_Down();
	void Move_Left();
	void Move_Right();

	//this loads our spritebase and our screen to draw on
	void Load_Base(SpriteBase *base, SDL_Surface *screen,SpriteBase *grey,SpriteBase *white);
	
	//this draws our entity's in their normal states
	void Draw();

	//this is for the player when he dies
	void Draw_Player_Dead();

	void Draw_Enemy_Dead();
	
	//this is for the enemies if the player eats the power-up
	void Draw_Scared();

    //this is called every frame for the enemies... its how we use Set_State(mode,time,mode)
	void Update_State();
	void Render();

	//this is incremented when we want to draw the next frame(used in all draw() functions)
    unsigned int Frame_Count;

	//for timing when to show the next frame again used in all drawing functions
	unsigned int Last_Update;

	//the original starting coordinates of the entity. used when things die
	int start_x; 
	int start_y;

	//used in Draw_Death() and Draw_Enemy_Death() just a counter to make him spin around
	int death_spin;

	int death_counter;

	int ammo; //how many bombs the player has
	int score; //the players current score
	int lives; //how many lives the player has left

	int ID;
	int Delay;

	int warps;

	private:
	
	int xPos;					 //current x position of the entity 
	int yPos;					 //current y position of the entity
	int direction;               //current direction the entity is moving

	//this is used to see what "mode" the enemies are in. they could be "active" (ie normally
	//walking around the maze) they could be in standby mode, meaning there inside the box, 
	//waiting to leave the box. or they could be in runaway mode, ie the player ate the big pill
	int mode; 
	int next_mode;
	

	//this is used in Update_State and Set_State... its the ticker for how long before switching states
	int update_counter;
	
	//this is the switch, to switch on update_state(), it is evaluated in update_state(), though
	bool changing_states;

	
	//this points to the same screen as data.screen
	SDL_Surface *screen;	

	//a "switch" used in Draw_Scared() to switch from grey to white
	bool show_grey;			
	
	//the spritebase's which holds all the frames for this entity
	SpriteBase* Sprite_Base;
	SpriteBase* White_Base;
	SpriteBase* Grey_Base;

};

#endif